==> helm-annotations-2.11.0-sources.jar: io/dekorate/helm/config/HelmChartConfig.java <==
package io.dekorate.helm.config;

import io.dekorate.kubernetes.config.ConfigKey;
import io.dekorate.kubernetes.config.Configuration;
import java.lang.String;
import io.dekorate.project.Project;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;
import io.sundr.builder.annotations.Buildable;

 /**
  * Generated
  */
  @Buildable(builderPackage = "io.fabric8.kubernetes.api.builder")
  public class HelmChartConfig extends Configuration{
  public HelmChartConfig() {
  }
  public HelmChartConfig(Project project,Map<ConfigKey,Object> attributes,Boolean enabled,String name,java.lang.String valuesRootAlias,java.lang.String description,java.lang.String version,java.lang.String icon,java.lang.String home,java.lang.String[] keywords,java.lang.String[] sources,java.lang.Boolean createTarFile,java.lang.String extension,java.lang.String notes,Maintainer[] maintainers,HelmDependency[] dependencies,ValueReference[] values) {
    super(project, attributes);
    this.enabled = enabled;
    this.name = name;
    this.valuesRootAlias = valuesRootAlias;
    this.description = description;
    this.version = version;
    this.icon = icon;
    this.home = home;
    this.keywords = keywords != null ? keywords : new java.lang.String[0];
    this.sources = sources != null ? sources : new java.lang.String[0];
    this.createTarFile = createTarFile;
    this.extension = extension;
    this.notes = notes;
    this.maintainers = maintainers != null ? maintainers : new io.dekorate.helm.config.Maintainer[0];
    this.dependencies = dependencies != null ? dependencies : new io.dekorate.helm.config.HelmDependency[0];
    this.values = values != null ? values : new io.dekorate.helm.config.ValueReference[0];
  }
  private java.lang.Boolean enabled;
  private java.lang.String name;
  private java.lang.String valuesRootAlias;
  private java.lang.String description;
  private java.lang.String version;
  private java.lang.String icon;
  private java.lang.String home;
  private java.lang.String[] keywords = new java.lang.String[0];
  private java.lang.String[] sources = new java.lang.String[0];
  private java.lang.Boolean createTarFile;
  private java.lang.String extension;
  private java.lang.String notes;
  private io.dekorate.helm.config.Maintainer[] maintainers = new io.dekorate.helm.config.Maintainer[0];
  private io.dekorate.helm.config.HelmDependency[] dependencies = new io.dekorate.helm.config.HelmDependency[0];
  private io.dekorate.helm.config.ValueReference[] values = new io.dekorate.helm.config.ValueReference[0];
  public java.lang.Boolean getEnabled() {
    return this.enabled;
  }
  public boolean isEnabled() {
    return this.enabled != null &&  this.enabled;
  }
  public java.lang.String getName() {
    return this.name;
  }
  public java.lang.String getValuesRootAlias() {
    return this.valuesRootAlias;
  }
  public java.lang.String getDescription() {
    return this.description;
  }
  public java.lang.String getVersion() {
    return this.version;
  }
  public java.lang.String getIcon() {
    return this.icon;
  }
  public java.lang.String getHome() {
    return this.home;
  }
  public java.lang.String[] getKeywords() {
    return this.keywords;
  }
  public java.lang.String[] getSources() {
    return this.sources;
  }
  public java.lang.Boolean getCreateTarFile() {
    return this.createTarFile;
  }
  public boolean isCreateTarFile() {
    return this.createTarFile != null &&  this.createTarFile;
  }
  public java.lang.String getExtension() {
    return this.extension;
  }
  public java.lang.String getNotes() {
    return this.notes;
  }
  public io.dekorate.helm.config.Maintainer[] getMaintainers() {
    return this.maintainers;
  }
  public io.dekorate.helm.config.HelmDependency[] getDependencies() {
    return this.dependencies;
  }
  public io.dekorate.helm.config.ValueReference[] getValues() {
    return this.values;
  }
  public static HelmChartConfigBuilder newHelmChartConfigBuilder() {
    return new HelmChartConfigBuilder();
  }
  public static io.dekorate.helm.config.HelmChartConfigBuilder newHelmChartConfigBuilderFromDefaults() {
    return new io.dekorate.helm.config.HelmChartConfigBuilder().withEnabled(true).withValuesRootAlias("app").withCreateTarFile(false).withExtension("tar.gz").withNotes("/NOTES.template.txt");
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HelmChartConfig that = (HelmChartConfig) o;
    if (enabled != null ? !enabled.equals(that.enabled) :that.enabled != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (valuesRootAlias != null ? !valuesRootAlias.equals(that.valuesRootAlias) :that.valuesRootAlias != null) return false;
    if (description != null ? !description.equals(that.description) :that.description != null) return false;
    if (version != null ? !version.equals(that.version) :that.version != null) return false;
    if (icon != null ? !icon.equals(that.icon) :that.icon != null) return false;
    if (home != null ? !home.equals(that.home) :that.home != null) return false;
    if (keywords != null ? !keywords.equals(that.keywords) :that.keywords != null) return false;
    if (sources != null ? !sources.equals(that.sources) :that.sources != null) return false;
    if (createTarFile != null ? !createTarFile.equals(that.createTarFile) :that.createTarFile != null) return false;
    if (extension != null ? !extension.equals(that.extension) :that.extension != null) return false;
    if (notes != null ? !notes.equals(that.notes) :that.notes != null) return false;
    if (maintainers != null ? !maintainers.equals(that.maintainers) :that.maintainers != null) return false;
    if (dependencies != null ? !dependencies.equals(that.dependencies) :that.dependencies != null) return false;
    if (values != null ? !values.equals(that.values) :that.values != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(enabled,  name,  valuesRootAlias,  description,  version,  icon,  home,  keywords,  sources,  createTarFile,  extension,  notes,  maintainers,  dependencies,  values,  super.hashCode());
  }
  
}

==> helm-annotations-2.11.5-sources.jar: io/dekorate/helm/config/HelmChartConfig.java <==
package io.dekorate.helm.config;

import io.dekorate.kubernetes.config.ConfigKey;
import io.dekorate.kubernetes.config.Configuration;
import java.lang.String;
import io.dekorate.project.Project;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;
import io.sundr.builder.annotations.Buildable;

 /**
  * Generated
  */
  @Buildable(builderPackage = "io.fabric8.kubernetes.api.builder")
  public class HelmChartConfig extends Configuration{
  public HelmChartConfig() {
  }
  public HelmChartConfig(Project project,Map<ConfigKey,Object> attributes,Boolean enabled,String name,java.lang.String apiVersion,java.lang.String valuesRootAlias,java.lang.String description,java.lang.String version,java.lang.String icon,java.lang.String home,java.lang.String[] keywords,java.lang.String[] sources,java.lang.Boolean createTarFile,java.lang.String extension,java.lang.String notes,java.lang.String inputFolder,java.lang.String outputFolder,Maintainer[] maintainers,HelmDependency[] dependencies,ValueReference[] values) {
    super(project, attributes);
    this.enabled = enabled;
    this.name = name;
    this.apiVersion = apiVersion;
    this.valuesRootAlias = valuesRootAlias;
    this.description = description;
    this.version = version;
    this.icon = icon;
    this.home = home;
    this.keywords = keywords != null ? keywords : new java.lang.String[0];
    this.sources = sources != null ? sources : new java.lang.String[0];
    this.createTarFile = createTarFile;
    this.extension = extension;
    this.notes = notes;
    this.inputFolder = inputFolder;
    this.outputFolder = outputFolder;
    this.maintainers = maintainers != null ? maintainers : new io.dekorate.helm.config.Maintainer[0];
    this.dependencies = dependencies != null ? dependencies : new io.dekorate.helm.config.HelmDependency[0];
    this.values = values != null ? values : new io.dekorate.helm.config.ValueReference[0];
  }
  private java.lang.Boolean enabled;
  private java.lang.String name;
  private java.lang.String apiVersion;
  private java.lang.String valuesRootAlias;
  private java.lang.String description;
  private java.lang.String version;
  private java.lang.String icon;
  private java.lang.String home;
  private java.lang.String[] keywords = new java.lang.String[0];
  private java.lang.String[] sources = new java.lang.String[0];
  private java.lang.Boolean createTarFile;
  private java.lang.String extension;
  private java.lang.String notes;
  private java.lang.String inputFolder;
  private java.lang.String outputFolder;
  private io.dekorate.helm.config.Maintainer[] maintainers = new io.dekorate.helm.config.Maintainer[0];
  private io.dekorate.helm.config.HelmDependency[] dependencies = new io.dekorate.helm.config.HelmDependency[0];
  private io.dekorate.helm.config.ValueReference[] values = new io.dekorate.helm.config.ValueReference[0];
  public java.lang.Boolean getEnabled() {
    return this.enabled;
  }
  public boolean isEnabled() {
    return this.enabled != null &&  this.enabled;
  }
  public java.lang.String getName() {
    return this.name;
  }
  public java.lang.String getApiVersion() {
    return this.apiVersion;
  }
  public java.lang.String getValuesRootAlias() {
    return this.valuesRootAlias;
  }
  public java.lang.String getDescription() {
    return this.description;
  }
  public java.lang.String getVersion() {
    return this.version;
  }
  public java.lang.String getIcon() {
    return this.icon;
  }
  public java.lang.String getHome() {
    return this.home;
  }
  public java.lang.String[] getKeywords() {
    return this.keywords;
  }
  public java.lang.String[] getSources() {
    return this.sources;
  }
  public java.lang.Boolean getCreateTarFile() {
    return this.createTarFile;
  }
  public boolean isCreateTarFile() {
    return this.createTarFile != null &&  this.createTarFile;
  }
  public java.lang.String getExtension() {
    return this.extension;
  }
  public java.lang.String getNotes() {
    return this.notes;
  }
  public java.lang.String getInputFolder() {
    return this.inputFolder;
  }
  public java.lang.String getOutputFolder() {
    return this.outputFolder;
  }
  public io.dekorate.helm.config.Maintainer[] getMaintainers() {
    return this.maintainers;
  }
  public io.dekorate.helm.config.HelmDependency[] getDependencies() {
    return this.dependencies;
  }
  public io.dekorate.helm.config.ValueReference[] getValues() {
    return this.values;
  }
  public static HelmChartConfigBuilder newHelmChartConfigBuilder() {
    return new HelmChartConfigBuilder();
  }
  public static io.dekorate.helm.config.HelmChartConfigBuilder newHelmChartConfigBuilderFromDefaults() {
    return new io.dekorate.helm.config.HelmChartConfigBuilder().withEnabled(true).withApiVersion("v2").withValuesRootAlias("app").withCreateTarFile(false).withExtension("tar.gz").withNotes("/NOTES.template.txt").withInputFolder("helm").withOutputFolder("helm");
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HelmChartConfig that = (HelmChartConfig) o;
    if (enabled != null ? !enabled.equals(that.enabled) :that.enabled != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (valuesRootAlias != null ? !valuesRootAlias.equals(that.valuesRootAlias) :that.valuesRootAlias != null) return false;
    if (description != null ? !description.equals(that.description) :that.description != null) return false;
    if (version != null ? !version.equals(that.version) :that.version != null) return false;
    if (icon != null ? !icon.equals(that.icon) :that.icon != null) return false;
    if (home != null ? !home.equals(that.home) :that.home != null) return false;
    if (keywords != null ? !keywords.equals(that.keywords) :that.keywords != null) return false;
    if (sources != null ? !sources.equals(that.sources) :that.sources != null) return false;
    if (createTarFile != null ? !createTarFile.equals(that.createTarFile) :that.createTarFile != null) return false;
    if (extension != null ? !extension.equals(that.extension) :that.extension != null) return false;
    if (notes != null ? !notes.equals(that.notes) :that.notes != null) return false;
    if (inputFolder != null ? !inputFolder.equals(that.inputFolder) :that.inputFolder != null) return false;
    if (outputFolder != null ? !outputFolder.equals(that.outputFolder) :that.outputFolder != null) return false;
    if (maintainers != null ? !maintainers.equals(that.maintainers) :that.maintainers != null) return false;
    if (dependencies != null ? !dependencies.equals(that.dependencies) :that.dependencies != null) return false;
    if (values != null ? !values.equals(that.values) :that.values != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(enabled,  name,  apiVersion,  valuesRootAlias,  description,  version,  icon,  home,  keywords,  sources,  createTarFile,  extension,  notes,  inputFolder,  outputFolder,  maintainers,  dependencies,  values,  super.hashCode());
  }
  
}
